ZoomPan class

Apply Zoom & Pan effect.

Implemented types

Constructors

ZoomPan({int? zoom, int? z, int? x, int? y, int? d, String? s, String? fps})
ZoomPan

Properties

d int?
Set the duration expression in number of frames. This sets for how many number of frames effect will last for single input image. Default is 90.
getter/setter pair
fps String?
Set the output frame rate, default is 25.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
name
no setteroverride
options Map<String, dynamic>
options
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
s String?
Set the output image size, default is hd720.
getter/setter pair
x int?
Set the x and y expression. Default is 0.
getter/setter pair
y int?
Set the x and y expression. Default is 0.
getter/setter pair
z int?
Set the zoom expression. Range is 1-10. Default is 1.
getter/setter pair
zoom int?
Set the zoom expression. Range is 1-10. Default is 1.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited